import 'package:flutter_test/flutter_test.dart';
import 'package:server/apis/auth.dart';
import 'package:server/apis/cart.dart';
import 'package:server/apis/orders.dart';
import 'package:server/apis/projects.dart';
import 'package:server/apis/shop.dart';
import 'package:server/apis/tokens.dart';

void main() {
  test('Спринт 2. Авторизация', () async {
    try {
      final response = await auth.login(
        'example123123333333@mail.ru',
        'string213123',
      );
      if (response != null) {
        expect(response['record']['email'], 'example123123333333@mail.ru');
      }
    } catch (e) {
      // ignore: avoid_print
      print(e);
    }
  });

  test('Создание заказа', () async {
    final productsList = await shop.getCatalog();
    final firstProduct = productsList['items'][0];

    try {
      final response = await orders.createOrder(firstProduct['id'], 10);
      if (response != null) {
        expect(response['count'], 10);
      }
    } catch (e) {
      // ignore: avoid_print
      print(e);
    }
  });

  test('Спринт 2. Создание пользователя', () async {
    try {
      final response = await auth.register(
        'example123123333333@mail2.ru',
        'string213123',
        'string213123',
        'testtest',
        'testtest',
        'testtest',
        'testtest',
        'testtest',
      );
      if (response != null) {
        expect(response['record']['firstname'], 'testtest');
      } else {
        expect('1', '2');
      }
    } catch (e) {
      // ignore: avoid_print
      print(e);
    }
  });

  test('Спринт 2. Получение каталога-3', () async {
    try {
      final response = await shop.getCatalog();
      if (response != null) {
        expect(response['perPage'], 30);
      }
    } catch (e) {
      print(e);
      return Error();
    }
  });

  test('Спринт 2. Акции и новости', () async {
    try {
      final response = await shop.getNews();
      if (response != null) {
        expect(response['perPage'], 30);
      }
    } catch (e) {
      print(e);
      return Error();
    }
  });

  test('Спринт 2.  Добавление в корзину', () async {
    try {
      final response = await cart.addToCart('string', 10);
      expect(response['count'], 10);
    } catch (e) {
      print(e);
      return Error();
    }
  });

  test('Спринт 2.Получение информации о профиле', () async {
    try {
      final response = await auth.getCurrentUser();
      if (response != null) {
        expect(response['firstname'], 'testtest');
      }
    } catch (e) {
      print(e);
      return Error();
    }
  });

  test('Спринт 2.Логаут пользователя', () async {
    try {
      final currentId = await tokens.getAccessToken();
      if (currentId != null) {
        final response = await auth.userLogout(currentId);
        return response.data;
      }
    } catch (e) {
      print(e);
      return Error();
    }
  });

  test('Создание проекта', () async {
    try {
      final response = await projects.createProject(
        '1233213',
        '123312321',
        '123321123',
        '123321',
        '123231',
        '123312',
        '123312',
      );
      if (response != null) {
        expect(response['title'], '1233213');
      }
    } catch (e) {
      // ignore: avoid_print
      print(e);
    }
  });
  test('Список проектов', () async {
    try {
      final response = await projects.getProjects();
      if (response != null) {
        expect(response['perPage'], 30);
      } else {
        expect('1', '2');
      }
    } catch (e) {
      // ignore: avoid_print
      print(e);
    }
  });
}
